@@ -1,5 +1,4 @@
 import json
-import logging
 import os
 import re
 from distutils.version import Version
@@ -7,13 +6,28 @@ from distutils.version import Version
 import kubernetes
 import urllib3
 from openshift.dynamic import DynamicClient
-from openshift.dynamic.exceptions import InternalServerError, NotFoundError
+from openshift.dynamic.exceptions import (
+    ConflictError,
+    InternalServerError,
+    NotFoundError,
+    ServerTimeoutError,
+)
 from urllib3.exceptions import ProtocolError
 
+from ocp_resources.logger import get_logger
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
-LOGGER = logging.getLogger(__name__)
+LOGGER = get_logger(name=__name__)
+
+DEFAULT_CLUSTER_RETRY_EXCEPTIONS = (
+    ConnectionAbortedError,
+    ConnectionResetError,
+    InternalServerError,
+    ServerTimeoutError,
+    ConflictError,
+)
+
 TIMEOUT = 240
 MAX_SUPPORTED_API_VERSION = "v1"
 
@@ -253,10 +267,12 @@ class Resource(object):
         ADMISSIONREGISTRATION_K8S_IO = "admissionregistration.k8s.io"
         APIEXTENSIONS_K8S_IO = "apiextensions.k8s.io"
         APIREGISTRATION_K8S_IO = "apiregistration.k8s.io"
+        APP_KUBERNETES_IO = "app.kubernetes.io"
         APPS = "apps"
         CDI_KUBEVIRT_IO = "cdi.kubevirt.io"
         CONFIG_OPENSHIFT_IO = "config.openshift.io"
         CONSOLE_OPENSHIFT_IO = "console.openshift.io"
+        FORKLIFT_KONVEYOR_IO = "forklift.konveyor.io"
         HCO_KUBEVIRT_IO = "hco.kubevirt.io"
         HOSTPATHPROVISIONER_KUBEVIRT_IO = "hostpathprovisioner.kubevirt.io"
         IMAGE_OPENSHIFT_IO = "image.openshift.io"
@@ -281,6 +297,7 @@ class Resource(object):
         PACKAGES_OPERATORS_COREOS_COM = "packages.operators.coreos.com"
         PROJECT_OPENSHIFT_IO = "project.openshift.io"
         RBAC_AUTHORIZATION_K8S_IO = "rbac.authorization.k8s.io"
+        RIPSAW_CLOUDBULLDOZER_IO = "ripsaw.cloudbulldozer.io"
         ROUTE_OPENSHIFT_IO = "route.openshift.io"
         SCHEDULING_K8S_IO = "scheduling.k8s.io"
         SECURITY_OPENSHIFT_IO = "security.openshift.io"
@@ -294,11 +311,13 @@ class Resource(object):
         TEMPLATE_OPENSHIFT_IO = "template.openshift.io"
         UPLOAD_CDI_KUBEVIRT_IO = "upload.cdi.kubevirt.io"
         V2V_KUBEVIRT_IO = "v2v.kubevirt.io"
+        VM_KUBEVIRT_IO = "vm.kubevirt.io"
 
     class ApiVersion:
         V1 = "v1"
         V1BETA1 = "v1beta1"
         V1ALPHA1 = "v1alpha1"
+        V1ALPHA3 = "v1alpha3"
 
     def __init__(
         self, name, client=None, teardown=True, timeout=TIMEOUT, privileged_client=None
@@ -369,6 +388,7 @@ class Resource(object):
     def clean_up(self):
         if os.environ.get("CNV_TEST_COLLECT_LOGS", "0") == "1":
             try:
+                LOGGER.info(f"Collecting data for {self.kind} {self.name}")
                 _collect_data(resource_object=self)
             except Exception as exception_:
                 LOGGER.warning(exception_)
@@ -601,14 +621,17 @@ class Resource(object):
         self.api().replace(body=resource_dict, name=self.name, namespace=self.namespace)
 
     @staticmethod
-    def _retry_etcd_changed(func):
+    def retry_cluster_exceptions(
+        func, exceptions_tuple=DEFAULT_CLUSTER_RETRY_EXCEPTIONS, **kwargs
+    ):
+
         sampler = TimeoutSampler(
             wait_timeout=10,
             sleep=1,
             func=func,
-            exceptions=InternalServerError,
-            exceptions_msg="etcdserver: leader changed",
+            exceptions=exceptions_tuple,
             print_log=False,
+            **kwargs,
         )
         for sample in sampler:
             return sample
@@ -636,7 +659,7 @@ class Resource(object):
             except TypeError:
                 yield cls(client=dyn_client, name=_resources.metadata.name)
 
-        return Resource._retry_etcd_changed(func=_get)
+        return Resource.retry_cluster_exceptions(func=_get)
 
     @property
     def instance(self):
@@ -650,7 +673,7 @@ class Resource(object):
         def _instance():
             return self.api().get(name=self.name)
 
-        return self._retry_etcd_changed(func=_instance)
+        return self.retry_cluster_exceptions(func=_instance)
 
     @property
     def labels(self):
@@ -857,10 +880,9 @@ class ResourceEditor(object):
     def update(self, backup_resources=False):
         """Prepares backup dicts (where necessary) and applies patches"""
         # prepare update dicts and backups
-        LOGGER.info("ResourceEdit: Backing up old data")
-
         resource_to_patch = []
         if backup_resources:
+            LOGGER.info("ResourceEdit: Backing up old data")
             if self.user_backups:
                 resource_to_patch = self._patches
                 self._backups = self.user_backups
@@ -909,12 +931,12 @@ class ResourceEditor(object):
         }
 
         # apply changes
-        self._apply_patches(
+        self._apply_patches_sampler(
             patches=patches_to_apply, action_text="Updating", action=self.action
         )
 
     def restore(self):
-        self._apply_patches(
+        self._apply_patches_sampler(
             patches=self._backups, action_text="Restoring", action=self.action
         )
 
@@ -1013,3 +1035,11 @@ class ResourceEditor(object):
                 resource.update_replace(
                     resource_dict=patch
                 )  # replace the resource metadata
+
+    def _apply_patches_sampler(self, patches, action_text, action):
+        return Resource.retry_cluster_exceptions(
+            func=self._apply_patches,
+            patches=patches,
+            action_text=action_text,
+            action=action,
+        )
