@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 
 
-from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
+from urllib3.exceptions import ProtocolError
+
 from ocp_resources.logger import get_logger
-from ocp_resources.resource import NamespacedResource
+from ocp_resources.resource import TIMEOUT, NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 from ocp_resources.virtual_machine import VirtualMachine
 
@@ -19,32 +20,16 @@ class VirtualMachineRestore(NamespacedResource):
     api_group = NamespacedResource.ApiGroup.SNAPSHOT_KUBEVIRT_IO
 
     def __init__(
-        self,
-        name=None,
-        namespace=None,
-        vm_name=None,
-        snapshot_name=None,
-        client=None,
-        teardown=True,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
+        self, name, namespace, vm_name, snapshot_name, client=None, teardown=True
     ):
         super().__init__(
-            name=name,
-            namespace=namespace,
-            client=client,
-            teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
+            name=name, namespace=namespace, client=client, teardown=teardown
         )
         self.vm_name = vm_name
         self.snapshot_name = snapshot_name
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         spec = res.setdefault("spec", {})
         spec.setdefault("target", {})[
             "apiGroup"
@@ -54,7 +39,7 @@ class VirtualMachineRestore(NamespacedResource):
         spec["virtualMachineSnapshotName"] = self.snapshot_name
         return res
 
-    def wait_complete(self, status=True, timeout=TIMEOUT_4MINUTES):
+    def wait_complete(self, status=True, timeout=TIMEOUT):
         """
         Wait for VirtualMachineRestore to be in status complete
 
@@ -72,7 +57,7 @@ class VirtualMachineRestore(NamespacedResource):
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
-            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
+            exceptions=ProtocolError,
             func=lambda: self.instance.get("status", {}).get("complete", None)
             == status,
         )
